'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.FIRST_GROUP_PATTERN = undefined;

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

exports.default = format;
exports.format_national_number_using_format = format_national_number_using_format;
exports.format_national_number = format_national_number;
exports.local_to_international_style = local_to_international_style;

var _common = require('./common');

var _metadata = require('../metadata.min');

var _metadata2 = _interopRequireDefault(_metadata);

var _parse = require('./parse');

var _metadata3 = require('./metadata');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// This is a port of Google Android `libphonenumber`'s
// `phonenumberutil.js` of 17th November, 2016.
//
// https://github.com/googlei18n/libphonenumber/commits/master/javascript/i18n/phonenumbers/phonenumberutil.js

function format() {
	var input = arguments.length <= 0 || arguments[0] === undefined ? '' : arguments[0];
	var format = arguments[1];
	var third_argument = arguments[2];

	// If the first argument object is expanded
	if (typeof input === 'string') {
		// If number is passed not as an object
		if (typeof third_argument === 'string') {
			input = { phone: input, country: format };
			format = third_argument;
		} else {
			input = { phone: input };
		}
	}

	var country_metadata = void 0;

	if (input.country) {
		country_metadata = _metadata2.default.countries[input.country];
	}

	var _parse_phone_number_a = (0, _parse.parse_phone_number_and_country_phone_code)(input.phone);

	var country_phone_code = _parse_phone_number_a.country_phone_code;
	var number = _parse_phone_number_a.number;


	if (country_phone_code) {
		// Check country restriction
		if (input.country && country_phone_code !== (0, _metadata3.get_phone_code)(country_metadata)) {
			return input.phone;
		}

		country_metadata = (0, _metadata3.get_metadata_by_country_phone_code)(country_phone_code, _metadata2.default);
	}

	if (!country_metadata) {
		return input.phone;
	}

	switch (format) {
		case 'International':
			if (!number) {
				return '+' + (0, _metadata3.get_phone_code)(country_metadata);
			}
			var national_number = format_national_number(number, 'International', false, country_metadata);
			return '+' + (0, _metadata3.get_phone_code)(country_metadata) + ' ' + national_number;

		case 'International_plaintext':
			return '+' + (0, _metadata3.get_phone_code)(country_metadata) + input.phone;

		case 'National':
			if (!number) {
				return '';
			}
			return format_national_number(number, 'National', false, country_metadata);
	}
}

// This was originally set to $1 but there are some countries for which the
// first group is not used in the national pattern (e.g. Argentina) so the $1
// group does not match correctly.  Therefore, we use \d, so that the first
// group actually used in the pattern will be matched.
var FIRST_GROUP_PATTERN = exports.FIRST_GROUP_PATTERN = /(\$\d)/;

function format_national_number_using_format(number, format, international, enforce_national_prefix, country_metadata) {
	var format_pattern_matcher = new RegExp((0, _metadata3.get_format_pattern)(format));

	var national_prefix_may_be_omitted = !enforce_national_prefix && (0, _metadata3.get_format_national_prefix_is_optional_when_formatting)(format, country_metadata);

	if (!international && !national_prefix_may_be_omitted) {
		var national_prefix_formatting_rule = (0, _metadata3.get_format_national_prefix_formatting_rule)(format, country_metadata);

		// If national prefix formatting rule is set
		// (e.g. it is not set for US)
		if (national_prefix_formatting_rule) {
			return number.replace(format_pattern_matcher, (0, _metadata3.get_format_format)(format).replace(FIRST_GROUP_PATTERN, national_prefix_formatting_rule));
		}
	}

	var formatted_number = number.replace(format_pattern_matcher, international ? (0, _metadata3.get_format_international_format)(format) : (0, _metadata3.get_format_format)(format));

	if (international) {
		return local_to_international_style(formatted_number);
	}

	return formatted_number;
}

function format_national_number(number, format_as, enforce_national_prefix, country_metadata) {
	var format = choose_format_for_number((0, _metadata3.get_formats)(country_metadata), number);

	if (!format) {
		return number;
	}

	return format_national_number_using_format(number, format, format_as === 'International', enforce_national_prefix, country_metadata);
}

function choose_format_for_number(available_formats, national_number) {
	var _iteratorNormalCompletion = true;
	var _didIteratorError = false;
	var _iteratorError = undefined;

	try {
		for (var _iterator = (0, _getIterator3.default)(available_formats), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
			var _format = _step.value;

			if ((0, _metadata3.get_format_leading_digits_patterns)(_format).length > 0) {
				// The last leading_digits_pattern is used here, as it is the most detailed
				var last_leading_digits_pattern = (0, _metadata3.get_format_leading_digits_patterns)(_format)[(0, _metadata3.get_format_leading_digits_patterns)(_format).length - 1];

				if (national_number.search(last_leading_digits_pattern) !== 0) {
					return;
				}
			}

			if ((0, _common.matches_entirely)(national_number, new RegExp((0, _metadata3.get_format_pattern)(_format)))) {
				return _format;
			}
		}
	} catch (err) {
		_didIteratorError = true;
		_iteratorError = err;
	} finally {
		try {
			if (!_iteratorNormalCompletion && _iterator.return) {
				_iterator.return();
			}
		} finally {
			if (_didIteratorError) {
				throw _iteratorError;
			}
		}
	}
}

// Removes brackets and replaces dashes with spaces.
//
// E.g. "(999) 111-22-33" -> "999 111 22 33"
//
function local_to_international_style(local) {
	return local
	// Remove brackets
	.replace(/[\(\)]/g, '')
	// Replace dashes with spaces
	.replace(/\-/g, ' ').trim();
}
//# sourceMappingURL=format.js.map